#[non_exhaustive]pub struct HoopedHandler { /* private fields */ }Expand description
Handler that wrap Handler to let it use middlewares.
Implementations
Sourceimpl HoopedHandler
impl HoopedHandler
Sourcepub fn new<H>(inner: H) -> HoopedHandlerwhere
H: Handler,
pub fn new<H>(inner: H) -> HoopedHandlerwhere
H: Handler,
Create new HoopedHandler.
Sourcepub fn hoops_mut(&mut self) -> &mut Vec<Arc<dyn Handler>>
pub fn hoops_mut(&mut self) -> &mut Vec<Arc<dyn Handler>>
Get current catcher’s middlewares mutable reference.
Sourcepub fn hoop<H>(self, hoop: H) -> HoopedHandlerwhere
H: Handler,
pub fn hoop<H>(self, hoop: H) -> HoopedHandlerwhere
H: Handler,
Add a handler as middleware, it will run the handler when error caught.