pub struct Logger {
pub log_status_error: bool,
}Expand description
A simple logger middleware.
Fields
log_status_error: boolWhether to log status error.
If true, the logger will try log StatusError information if response body is ResBody::Error.
Note: If you have handled the error before logging and the body is not ResBody::Error,
the error information cannot be recorded.
Implementations
Sourceimpl Logger
impl Logger
Sourcepub fn log_status_error(self, log_status_error: bool) -> Logger
pub fn log_status_error(self, log_status_error: bool) -> Logger
Set whether to log StatusError information if response body is ResBody::Error.
Note: If you have handled the error before logging and the body is not ResBody::Error,
the error information cannot be recorded.