Scribe

Trait Scribe 

pub trait Scribe {
    // Required method
    fn render(self, res: &mut Response);
}
Scribe is used to write data to Response.

Scribe is simpler than Writer and it implements Writer. It does not require the use of Depot and Request.

There are several built-in implementations of the Scribe trait.

Required Methods

fn render(self, res: &mut Response)

Render data to Response.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Scribe for &'static str

Source

fn render(self, res: &mut Response)

Source

impl Scribe for &String

Source

fn render(self, res: &mut Response)

Source

impl Scribe for ()

Source

fn render(self, _res: &mut Response)

Source

impl Scribe for Infallible

Source

fn render(self, _res: &mut Response)

Source

impl Scribe for String

Source

fn render(self, res: &mut Response)

Implementors