pub trait Scribe { // Required method fn render(self, res: &mut Response); }
Scribe is used to write data to Response.
Scribe
Response
Scribe is simpler than Writer and it implements Writer. It does not require the use of Depot and Request.
Writer
There are several built-in implementations of the Scribe trait.
Render data to Response.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".